Django Toolkit
==============

.. image:: https://travis-ci.org/luizalabs/django-toolkit.svg?branch=master
    :target: https://travis-ci.org/luizalabs/django-toolkit

.. image:: https://codecov.io/gh/luizalabs/django-toolkit/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/luizalabs/django-toolkit

.. image:: https://readthedocs.org/projects/luizalabs-django-toolkit/badge/?version=stable
  :target: http://django-toolkit.readthedocs.io/en/stable/

.. image:: https://badge.fury.io/py/luizalabs-django-toolkit.svg
    :target: https://badge.fury.io/py/luizalabs-django-toolkit

Our set of tools to develop projects using the Django framework

Instalation
-----------

.. code-block:: bash

   pip install luizalabs-django-toolkit


More
----

* `Documentation <http://django-toolkit.readthedocs.io/en/stable/>`_
